==> manydhcp2.5.2.tar.bz2: manydhcp/service/zadr.php <==
<?php
///////////////////////////////////////////////////
//2010 (C)
//Карпухин Павел
///////////////////////////////////////////////////

$lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) include "../lang/".$lang."/".$lang.".php";
     else include "../lang/ru/ru.php";

if(!isset($title)) $title = $TEXT['menu-btn26'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

if(empty($_POST['addr_old'])) {puterror($result2['skin'],$TEXT['error-grp1']); require_once "../utils/bottom_adm.php"; exit();}
if(strlen($_POST['addr_old'])>15) {puterror($result2['skin'],$TEXT['error-grp3']); require_once "../utils/bottom_adm.php"; exit();}
if(empty($_POST['addr_new'])) {puterror($result2['skin'],$TEXT['error-grp2']); require_once "../utils/bottom_adm.php"; exit();}
if(strlen($_POST['addr_new'])>15) {puterror($result2['skin'],$TEXT['error-grp4']); require_once "../utils/bottom_adm.php"; exit();}

$ipmass = Array(",","ю","Ю","..","...");
$_POST['addr_old'] = trim(str_replace($ipmass,".",$_POST['addr_old']));
$_POST['addr_new'] = trim(str_replace($ipmass,".",$_POST['addr_new']));

if(isset($_POST['addr_old'])) $addr_old=trim($_POST['addr_old']);
 else $addr_old="";
  if (empty($addr_old)) {puterror($result2['skin'],$TEXT['error-grp5']); require_once "../utils/bottom_adm.php"; exit();}

if(isset($_POST['addr_new'])) $addr_new=trim($_POST['addr_new']);
 else $addr_new="";
  if (empty($addr_new)) {puterror($result2['skin'],$TEXT['error-grp5']); require_once "../utils/bottom_adm.php"; exit();}

$_POST['addr_old'] = rep($_POST['addr_old']);
$_POST['addr_new'] = rep($_POST['addr_new']);

$delimiter =".";
$sour = $addr_old;
$dest = $addr_new;
$n = 0;

//function disabled by php > 5.5.3
////import_request_variables("gP", "in_");
// before using only ->  while(list($id,$value) = @each($in_ip))

 while(list($id2,$value2) = @each($_POST)) {
  if($id2 == "ip") {
   while(list($id,$value) = each($value2)) {
     if($id > 0 && $value == 'on')
     {
      $query3 = "SELECT ip_id, ip_addr FROM `tbl_ip` WHERE `ip_id`= $id";
       $result3 = mysql_query($query3);
        if(!$result3) {puterror($result2['skin'],$TEXT['error-tbl2']); require_once "../utils/bottom_adm.php"; exit();}
         $result4 = mysql_fetch_array($result3,MYSQL_ASSOC);

      $new_addr = str_replace($sour,$dest,$result4['ip_addr']);
      $query_ip = "UPDATE `tbl_ip` SET `ip_addr` = '".$new_addr."' WHERE `ip_id` = '".$result4['ip_id']."' ";
      $result_ip = mysql_query($query_ip);
       if(!$result_ip) {puterror($result2['skin'],$TEXT['error-tbl2']); require_once "../utils/bottom_adm.php"; exit();}

     $log_id .= $id.", ";
     $n++;
     }
    }
   }
  }
//*************************************
//Информация для лога
$addr = explode($delimiter,$sour,4);
  $oct1 = substr($addr['0'],0,1);
   if($oct1 == '0')
     {
      $oct_res1 = substr($addr['0'],1,1);
      if($oct_res1 == '0')
       {
        $oct_result1 = substr($addr['0'],2,3);
       } else $oct_result1 = substr($addr['0'],1,3);
     } else $oct_result1 = $addr['0'];

  $oct2 = substr($addr['1'],0,1);
   if($oct2 == '0')
    {
     $oct_res2 = substr($addr['1'],1,1);
      if($oct_res2 == '0')
       {
        $oct_result2 = substr($addr['1'],2,3);
       } else $oct_result2 = substr($addr['1'],1,3);
    } else $oct_result2 = $addr['1'];

   $oct3 = substr($addr['2'],0,1);
    if($oct3 == '0')
      {
       $oct_res3 = substr($addr['2'],1,1);
        if($oct_res3 == '0')
          {
           $oct_result3 = substr($addr['2'],2,3);
          } else $oct_result3 = substr($addr['2'],1,3);
      } else $oct_result3 = $addr['2'];

    $oct4 = substr($addr['3'],0,1);
      if($oct4 == '0')
        {
         $oct_res4 = substr($addr['3'],1,1);
         if($oct_res4 == '0')
           {
            $oct_result4 = substr($addr['3'],2,3);
           } else $oct_result4 = substr($addr['3'],1,3);
        } else $oct_result4 = $addr['3'];
$sour_log = $oct_result1.".".$oct_result2.".".$oct_result3.".".$oct_result4;
$sour_log = trim(str_replace($ipmass,".",$sour_log));

$addr12 = explode($delimiter,$dest,4);
  $oct12 = substr($addr12['0'],0,1);
   if($oct12 == '0')
     {
      $oct_res12 = substr($addr12['0'],1,1);
      if($oct_res12 == '0')
       {
        $oct_result12 = substr($addr12['0'],2,3);
       } else $oct_result12 = substr($addr12['0'],1,3);
     } else $oct_result12 = $addr12['0'];

  $oct22 = substr($addr12['1'],0,1);
   if($oct22 == '0')
    {
     $oct_res22 = substr($addr12['1'],1,1);
      if($oct_res22 == '0')
       {
        $oct_result22 = substr($addr12['1'],2,3);
       } else $oct_result22 = substr($addr12['1'],1,3);
    } else $oct_result22 = $addr12['1'];

   $oct32 = substr($addr12['2'],0,1);
    if($oct32 == '0')
      {
       $oct_res32 = substr($addr12['2'],1,1);
        if($oct_res32 == '0')
          {
           $oct_result32 = substr($addr12['2'],2,3);
          } else $oct_result32 = substr($addr12['2'],1,3);
      } else $oct_result32 = $addr12['2'];

    $oct42 = substr($addr12['3'],0,1);
      if($oct42 == '0')
        {
         $oct_res42 = substr($addr12['3'],1,1);
         if($oct_res42 == '0')
           {
            $oct_result42 = substr($addr12['3'],2,3);
           } else $oct_result4 = substr($addr12['3'],1,3);
        } else $oct_result4 = $addr12['3'];
$dest_log = $oct_result12.".".$oct_result22.".".$oct_result32.".".$oct_result42;
$dest_log = trim(str_replace($ipmass,".",$dest_log));

$ip = $_SERVER['REMOTE_ADDR'];
$doing = $TEXT['log-grp-zadr'];
$what = $sour_log.$TEXT['log-nd8'].$dest_log.$TEXT['log-grp-zadr2'].$n.$TEXT['log-grp-zadr3'].$TEXT['log-id'].substr($log_id,0,-2);
$who = $result2['familiya']." ".$result2['name'];
//*************************************
$query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
   if(mysql_query($query2))
    {
    echo "<html><head>
          <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=../addresses/index.php' />
          </head></html>";
    } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
require_once "../utils/bottom_adm.php";
?>

==> manydhcp2.7.2.tar.bz2: manydhcp/service/zadr.php <==
<?php
///////////////////////////////////////////////////
//2010 (C)
//Карпухин Павел
///////////////////////////////////////////////////

$lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) {include "../lang/".$lang."/".$lang.".php";}
     else {include "../lang/ru/ru.php";}

$title = $TEXT['menu-btn26'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

if(empty($_POST['addr_old'])) {puterror($result2['skin'],$TEXT['error-grp1']); require_once "../utils/bottom_adm.php"; exit();}
if(strlen($_POST['addr_old'])>15) {puterror($result2['skin'],$TEXT['error-grp3']); require_once "../utils/bottom_adm.php"; exit();}
if(empty($_POST['addr_new'])) {puterror($result2['skin'],$TEXT['error-grp2']); require_once "../utils/bottom_adm.php"; exit();}
if(strlen($_POST['addr_new'])>15) {puterror($result2['skin'],$TEXT['error-grp4']); require_once "../utils/bottom_adm.php"; exit();}

$ipmass = Array(",","ю","Ю","..","...");
$_POST['addr_old'] = trim(str_replace($ipmass,".",$_POST['addr_old']));
$_POST['addr_new'] = trim(str_replace($ipmass,".",$_POST['addr_new']));

if(isset($_POST['addr_old'])) {$addr_old=trim($_POST['addr_old']);}
 else {$addr_old="";}
  if(empty($addr_old)) {puterror($result2['skin'],$TEXT['error-grp5']); require_once "../utils/bottom_adm.php"; exit();}

if(isset($_POST['addr_new'])) {$addr_new=trim($_POST['addr_new']);}
 else {$addr_new="";}
  if(empty($addr_new)) {puterror($result2['skin'],$TEXT['error-grp5']); require_once "../utils/bottom_adm.php"; exit();}

$_POST['addr_old'] = rep($_POST['addr_old']);
$_POST['addr_new'] = rep($_POST['addr_new']);

$delimiter =".";
$sour = $addr_old;
$dest = $addr_new;
$n = 0;

//function disabled by php > 5.5.3
////import_request_variables("gP", "in_");
// before using only ->  while(list($id,$value) = @each($in_ip))

 while(list($id2,$value2) = each($_POST)) {
  if($id2 == "ip") {
   while(list($id,$value) = each($value2)) {
     if($id > 0 && $value == 'on')
     {
      $query3 = "SELECT ip_id, ip_addr FROM `tbl_ip` WHERE `ip_id`= $id";
       $result3 = mysqli_query($dbcnx,$query3);
        if(!$result3) {puterror($result2['skin'],$TEXT['error-tbl2']); require_once "../utils/bottom_adm.php"; exit();}
         $result4 = mysqli_fetch_array($result3,MYSQLI_ASSOC);

      $new_addr = str_replace($sour,$dest,$result4['ip_addr']);
      $query_ip = "UPDATE `tbl_ip` SET `ip_addr` = '".$new_addr."' WHERE `ip_id` = '".$result4['ip_id']."' ";
      $result_ip = mysqli_query($dbcnx,$query_ip);
       if(!$result_ip) {puterror($result2['skin'],$TEXT['error-tbl2']); require_once "../utils/bottom_adm.php"; exit();}

     $log_id .= $id.", ";
     $n++;
     }
    }
   }
  }
//*************************************
//Информация для лога
$addr = explode($delimiter,$sour,4);
  $oct1 = substr($addr['0'],0,1);
   if($oct1 == '0')
     {
      $oct_res1 = substr($addr['0'],1,1);
      if($oct_res1 == '0')
       {
        $oct_result1 = substr($addr['0'],2,3);
       } else {$oct_result1 = substr($addr['0'],1,3);}
     } else {$oct_result1 = $addr['0'];}

  $oct2 = substr($addr['1'],0,1);
   if($oct2 == '0')
    {
     $oct_res2 = substr($addr['1'],1,1);
      if($oct_res2 == '0')
       {
        $oct_result2 = substr($addr['1'],2,3);
       } else {$oct_result2 = substr($addr['1'],1,3);}
    } else {$oct_result2 = $addr['1'];}

   $oct3 = substr($addr['2'],0,1);
    if($oct3 == '0')
      {
       $oct_res3 = substr($addr['2'],1,1);
        if($oct_res3 == '0')
          {
           $oct_result3 = substr($addr['2'],2,3);
          } else {$oct_result3 = substr($addr['2'],1,3);}
      } else {$oct_result3 = $addr['2'];}

    $oct4 = substr($addr['3'],0,1);
      if($oct4 == '0')
        {
         $oct_res4 = substr($addr['3'],1,1);
         if($oct_res4 == '0')
           {
            $oct_result4 = substr($addr['3'],2,3);
           } else {$oct_result4 = substr($addr['3'],1,3);}
        } else {$oct_result4 = $addr['3'];}
$sour_log = $oct_result1.".".$oct_result2.".".$oct_result3.".".$oct_result4;
$sour_log = trim(str_replace($ipmass,".",$sour_log));

$addr12 = explode($delimiter,$dest,4);
  $oct12 = substr($addr12['0'],0,1);
   if($oct12 == '0')
     {
      $oct_res12 = substr($addr12['0'],1,1);
      if($oct_res12 == '0')
       {
        $oct_result12 = substr($addr12['0'],2,3);
       } else {$oct_result12 = substr($addr12['0'],1,3);}
     } else {$oct_result12 = $addr12['0'];}

  $oct22 = substr($addr12['1'],0,1);
   if($oct22 == '0')
    {
     $oct_res22 = substr($addr12['1'],1,1);
      if($oct_res22 == '0')
       {
        $oct_result22 = substr($addr12['1'],2,3);
       } else {$oct_result22 = substr($addr12['1'],1,3);}
    } else {$oct_result22 = $addr12['1'];}

   $oct32 = substr($addr12['2'],0,1);
    if($oct32 == '0')
      {
       $oct_res32 = substr($addr12['2'],1,1);
        if($oct_res32 == '0')
          {
           $oct_result32 = substr($addr12['2'],2,3);
          } else {$oct_result32 = substr($addr12['2'],1,3);}
      } else {$oct_result32 = $addr12['2'];}

    $oct42 = substr($addr12['3'],0,1);
      if($oct42 == '0')
        {
         $oct_res42 = substr($addr12['3'],1,1);
         if($oct_res42 == '0')
           {
            $oct_result42 = substr($addr12['3'],2,3);
           } else {$oct_result4 = substr($addr12['3'],1,3);}
        } else {$oct_result4 = $addr12['3'];}
$dest_log = $oct_result12.".".$oct_result22.".".$oct_result32.".".$oct_result42;
$dest_log = trim(str_replace($ipmass,".",$dest_log));

$ip = $_SERVER['REMOTE_ADDR'];
$doing = $TEXT['log-grp-zadr'];
$what = $sour_log.$TEXT['log-nd8'].$dest_log.$TEXT['log-grp-zadr2'].$n.$TEXT['log-grp-zadr3'].$TEXT['log-id'].substr($log_id,0,-2);
$who = $result2['familiya']." ".$result2['name'];
//*************************************
$query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
   if(mysqli_query($dbcnx,$query2))
    {
    echo "<html><head>
          <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=../addresses/index.php' />
          </head></html>";
    } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
require_once "../utils/bottom_adm.php";
?>
